| edit_speed | R Documentation |
Changes travel time between consecutive stops by dividing it by a speed multiplier. Dwell times are preserved and all downstream times are shifted.
edit_speed(gtfs, trips = "all", stops = "all", factor)
gtfs |
A GTFS object. |
trips |
Character trip IDs or '"all"'. |
stops |
Character stop IDs or '"all"'. A segment is edited when either endpoint is selected. |
factor |
One positive speed multiplier. For example, '2' halves segment travel times. |
A modified 'wizardgtfs' object.
[GTFSwizard::get_speeds()], [GTFSwizard::get_durations()]
edited <- edit_speed(
for_rail_gtfs,
trips = for_rail_gtfs$trips$trip_id[1:2],
stops = "all",
factor = 1.25
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.