Selects a UTM zone from the geographic centroid, or a polar stereographic CRS outside UTM's latitude range.
Examples
shapes <- get_shapes_sf(for_rail_gtfs)$shapes
metric_shapes <- latlon2epsg(shapes)
Selects a UTM zone from the geographic centroid, or a polar stereographic CRS outside UTM's latitude range.
shapes <- get_shapes_sf(for_rail_gtfs)$shapes
metric_shapes <- latlon2epsg(shapes)