| get_shapes | R Documentation |
Builds one shape for each unique ordered stop pattern and assigns it to the corresponding trips.
get_shapes(gtfs)
gtfs |
A GTFS object. |
Consecutive stop coordinates are connected directly. The result is useful for visualization and approximate distance analysis, but it is not a map-matched representation of the vehicle path.
A 'wizardgtfs' object with a new 'shapes' table and updated 'trips$shape_id'.
[GTFSwizard::get_shapes_sf()], [GTFSwizard::get_shapes_df()]
gtfs_with_shapes <- get_shapes(for_rail_gtfs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.