plot_hubs: Plot Transit Hubs

View source: R/plot_.R

plot_hubsR Documentation

Plot Transit Hubs

Description

Plot Transit Hubs

Usage

plot_hubs(gtfs, i = 0.05)

Arguments

gtfs

A GTFS object.

i

Proportion of stops with the most routes to retain.

Details

To keep dense networks readable, at most 40 of the highest-ranked stops are drawn. Ranking uses distinct route count and then trip count.

Value

A 'ggplot' map.

See Also

[GTFSwizard::get_hubs()]

Examples

plot_hubs(for_rail_gtfs, i = 0.1)


GTFSwizard documentation built on Aug. 21, 2026, 5:16 p.m.