| plot_hubs | R Documentation |
Plot Transit Hubs
plot_hubs(gtfs, i = 0.05)
gtfs |
A GTFS object. |
i |
Proportion of stops with the most routes to retain. |
To keep dense networks readable, at most 40 of the highest-ranked stops are drawn. Ranking uses distinct route count and then trip count.
A 'ggplot' map.
[GTFSwizard::get_hubs()]
plot_hubs(for_rail_gtfs, i = 0.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.