| plot_routefrequency | R Documentation |
Creates a heatmap of scheduled departures by route, hour, and service pattern. The tile fill is the number of scheduled trips.
plot_routefrequency(gtfs, route = NULL, top_n = 25L)
gtfs |
A GTFS object. |
route |
Optional character vector of route IDs. 'NULL' includes all routes after applying 'top_n'. |
top_n |
Maximum number of routes to display when 'route' is 'NULL'. |
A 'ggplot' object.
[GTFSwizard::get_frequency()]
plot_routefrequency(
for_rail_gtfs,
route = for_rail_gtfs$routes$route_id[1:2]
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.