plot_serviceheatmap: Plot Average Scheduled Departures by Weekday and Hour

View source: R/plot_service_planning.R

plot_serviceheatmapR Documentation

Plot Average Scheduled Departures by Weekday and Hour

Description

Creates a heatmap of average scheduled departures on active service dates.

Usage

plot_serviceheatmap(gtfs)

Arguments

gtfs

A GTFS object.

Value

A 'ggplot' object. Each tile is a weekday-hour combination and its fill is the mean number of scheduled trip departures per active date.

References

[GTFS Schedule Reference](https://gtfs.org/documentation/schedule/reference/)

Examples

plot_serviceheatmap(for_rail_gtfs)


GTFSwizard documentation built on Aug. 21, 2026, 5:16 p.m.