View source: R/plot_service_planning.R
| plot_serviceheatmap | R Documentation |
Creates a heatmap of average scheduled departures on active service dates.
plot_serviceheatmap(gtfs)
gtfs |
A GTFS object. |
A 'ggplot' object. Each tile is a weekday-hour combination and its fill is the mean number of scheduled trip departures per active date.
[GTFS Schedule Reference](https://gtfs.org/documentation/schedule/reference/)
plot_serviceheatmap(for_rail_gtfs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.