View source: R/plot_service_planning.R
| plot_servicespan | R Documentation |
Shows the first departure and final arrival for route and service-pattern combinations. The longest and most frequently operated route-pattern combinations are retained when the feed is large.
plot_servicespan(gtfs, top_n = 30L)
gtfs |
A GTFS object. |
top_n |
Maximum number of route-pattern combinations to display. |
A 'ggplot' object. Each horizontal line is one route and service pattern; its endpoints are scheduled clock hours.
[GTFS Routes, Stops, and Trips](https://gtfs.org/documentation/schedule/examples/routes-stops-trips/)
plot_servicespan(for_rail_gtfs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.